"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.commission
from eis.commission.api.commission_agreement_products_api import CommissionAgreementProductsApi  # noqa: E501


class TestCommissionAgreementProductsApi(unittest.TestCase):
    """CommissionAgreementProductsApi unit test stubs"""

    def setUp(self):
        self.api = CommissionAgreementProductsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_commission_agreement_product(self):
        """Test case for create_commission_agreement_product

        Create the commission agreement product  # noqa: E501
        """
        pass

    def test_delete_commission_agreement_product(self):
        """Test case for delete_commission_agreement_product

        Delete the commission agreement product  # noqa: E501
        """
        pass

    def test_get_commission_agreement_product(self):
        """Test case for get_commission_agreement_product

        Retrieve the commission agreement product  # noqa: E501
        """
        pass

    def test_list_commission_agreement_products(self):
        """Test case for list_commission_agreement_products

        List commission agreement products  # noqa: E501
        """
        pass

    def test_update_commission_agreement_product(self):
        """Test case for update_commission_agreement_product

        Update the commission agreement product  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
