"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.commission
from eis.commission.api.commission_agreements_api import CommissionAgreementsApi  # noqa: E501


class TestCommissionAgreementsApi(unittest.TestCase):
    """CommissionAgreementsApi unit test stubs"""

    def setUp(self):
        self.api = CommissionAgreementsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_commission_agreement(self):
        """Test case for create_commission_agreement

        Create the commission agreement  # noqa: E501
        """
        pass

    def test_delete_commission_agreement(self):
        """Test case for delete_commission_agreement

        Delete the commission agreement  # noqa: E501
        """
        pass

    def test_get_commission_agreement(self):
        """Test case for get_commission_agreement

        Retrieve the commission agreement  # noqa: E501
        """
        pass

    def test_list_commission_agreements(self):
        """Test case for list_commission_agreements

        List commission agreements  # noqa: E501
        """
        pass

    def test_patch_commission_agreement_status(self):
        """Test case for patch_commission_agreement_status

        Update the commission agreement status  # noqa: E501
        """
        pass

    def test_update_commission_agreement(self):
        """Test case for update_commission_agreement

        Update the commission agreement  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
