"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.commission
from eis.commission.api.commissions_api import CommissionsApi  # noqa: E501


class TestCommissionsApi(unittest.TestCase):
    """CommissionsApi unit test stubs"""

    def setUp(self):
        self.api = CommissionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_commission(self):
        """Test case for create_commission

        Create the commission  # noqa: E501
        """
        pass

    def test_delete_commission(self):
        """Test case for delete_commission

        Delete the commission  # noqa: E501
        """
        pass

    def test_estimate_commission(self):
        """Test case for estimate_commission

        Retrieve the estimate commissions  # noqa: E501
        """
        pass

    def test_get_commission(self):
        """Test case for get_commission

        Retrieve the commission  # noqa: E501
        """
        pass

    def test_list_commissions(self):
        """Test case for list_commissions

        List commissions  # noqa: E501
        """
        pass

    def test_update_commission(self):
        """Test case for update_commission

        Update the commission  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
