"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.commission
from eis.commission.api.commission_settlements_api import CommissionSettlementsApi  # noqa: E501


class TestCommissionSettlementsApi(unittest.TestCase):
    """CommissionSettlementsApi unit test stubs"""

    def setUp(self):
        self.api = CommissionSettlementsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_commission_settlement(self):
        """Test case for create_commission_settlement

        Create the commission settlement  # noqa: E501
        """
        pass

    def test_delete_commission_settlement(self):
        """Test case for delete_commission_settlement

        Delete the commission settlement  # noqa: E501
        """
        pass

    def test_get_commission_settlement(self):
        """Test case for get_commission_settlement

        Retrieve the commission settlement  # noqa: E501
        """
        pass

    def test_list_commission_settlements(self):
        """Test case for list_commission_settlements

        List commission settlements  # noqa: E501
        """
        pass

    def test_publish_commission_settlements(self):
        """Test case for publish_commission_settlements

        Create the commission settlement publish  # noqa: E501
        """
        pass

    def test_update_commission_settlement(self):
        """Test case for update_commission_settlement

        Update the commission settlement  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
