"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import unittest

import eis.commission
from eis.commission.api.commission_agreement_versions_api import CommissionAgreementVersionsApi  # noqa: E501


class TestCommissionAgreementVersionsApi(unittest.TestCase):
    """CommissionAgreementVersionsApi unit test stubs"""

    def setUp(self):
        self.api = CommissionAgreementVersionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_commission_agreement_version(self):
        """Test case for create_commission_agreement_version

        Create the commission agreement version  # noqa: E501
        """
        pass

    def test_delete_commission_agreement_version(self):
        """Test case for delete_commission_agreement_version

        Delete the commission agreement version  # noqa: E501
        """
        pass

    def test_get_commission_agreement_version(self):
        """Test case for get_commission_agreement_version

        Retrieve the commission agreement version  # noqa: E501
        """
        pass

    def test_list_commission_agreement_versions(self):
        """Test case for list_commission_agreement_versions

        List commission agreement versions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
