"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.commission
from eis.commission.model.create_commission_item_request_dto import CreateCommissionItemRequestDto
globals()['CreateCommissionItemRequestDto'] = CreateCommissionItemRequestDto
from eis.commission.model.create_commission_request_dto import CreateCommissionRequestDto


class TestCreateCommissionRequestDto(unittest.TestCase):
    """CreateCommissionRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateCommissionRequestDto(self):
        """Test CreateCommissionRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateCommissionRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
