"""
    EMIL CommissionService

    The EMIL CommissionService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.commission
from eis.commission.model.update_commission_settlement_request_dto import UpdateCommissionSettlementRequestDto


class TestUpdateCommissionSettlementRequestDto(unittest.TestCase):
    """UpdateCommissionSettlementRequestDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUpdateCommissionSettlementRequestDto(self):
        """Test UpdateCommissionSettlementRequestDto"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UpdateCommissionSettlementRequestDto()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
